#! /bin/sh
#
#   Module name 		: env.sh 
#   Date of last delta		: 12/7/0
#   Release number		: 1.3


# Script name : env.sh
# Purpose     : Minimum environment setup.
# Author      : S. Roberts
# Revision    : 1.00

PATH=$PATH:. ; export PATH

# Fix to make Linux "echo" process escape characters
os=`uname -s`
if [ "x${os}" = "xLinux" ]
then
	. linfix.sh
fi


set_attrs()
{
	case "$TERM" in
		vt100 | vt220 | vt320 | xterm | ansi )
					st_bl=`tput bold 2>/dev/null`;
					st_us=`tput smul 2>/dev/null`;
					norm=`tput sgr0 2>/dev/null`;;

		* )			st_bl=;
					st_us=;
					norm=;;
	esac
}


menu()
{
	cls.sh
	echo
	echo "$spc        $st_us $PROD ENVIRONMENT ADMINISTRATION $norm  Rev $rev"
	echo
	echo "$spc 1)$st_bl createnv.sh $norm         Creates a minimum BBENV"
	echo "$spc 2)$st_bl viewenv.sh $norm          View a BBENV"
	echo "$spc 3)$st_bl modenv.sh $norm           Edits a BBENV"
	echo "$spc 4)$st_bl findenv.sh $norm          Finds all BBENV files"
	echo
	echo "$spc '?' or '<NUMBER>?' for HELP, '^' to GO BACK or 'q' to QUIT\n"
}


pause()
{
	echo
	echo "$spc Press [RETURN] to continue: \c"
	read nothing
}


endhelp()
{
	echo "$spc Press [RETURN] to continue: $st_bl\c"
	read menu_ret
	echo "$norm\c"
}


help_0()
{
	echo
	echo "$spc The $PROD Environment Administration utility provides the"
	echo "$spc user with an easy way to manage the $PROD environment"
	echo "$spc variables file."
	echo
	echo "$spc The options allow the user to create a minimum environment"
	echo "$spc variable file, to examine or edit the contents of an existing"
	echo "$spc environment variable file, or to find and display all of the"
	echo "$spc environment variable files that are on the system."
	echo
}


help_1()
{
	echo
	echo "$spc This option creates a minimum $PROD environment file called"
	echo "$spc BBENV.  In order to do this, the user is prompted for the"
	echo "$spc names of the $PROD system software directory, the directory"
	echo "$spc in which the BBENV file is to be created, the $PROD banner name"
	echo "$spc and the name of the Terminal Definition File (TDF).  It then"
	echo "$spc creates a minimum BBENV file using the environment variables"
	echo "$spc BBSEARCH, BBSIGNON, BBTERM, BBDEBUG and BBLIB."
	echo
}


help_2()
{
	echo
	echo "$spc This option prompts the user for the path of a BBENV file,"
	echo "$spc and then uses 'vi' to view it.  The file cannot be modified."
	echo
}


help_3()
{
	echo
	echo "$spc This option uses the UBL utility 'bbenvmod' to modify the"
	echo "$spc current $PROD environment variable file or a different BBENV"
	echo "$spc if one is specified."
	echo
}


help_4()
{
	echo
	echo "$spc This option finds all the BBENV files on the system and then"
	echo "$spc displays them on the screen."
	echo
}


check_4_quit()
{
	if [ $? = "1" ]
	then
		exit 1
	fi
}


# Main
rev="1.00"
if [ -n "`pwd | grep usql`" ] ; then PROD="U/SQL" ; else PROD="UBL" ; fi
set_attrs
spc=""
ex_flag1=false
while [ $ex_flag1 = false ]
do
	menu
	echo "$spc Select option: $st_bl\c"
	read opt
	echo "$norm\c"
	case $opt in
		1 )		createnv.sh;
				check_4_quit;
				pause;;
		2 )		viewenv.sh;
				check_4_quit;;
		3 )		modenv.sh;
				check_4_quit;
				pause;;
		4 )		findenv.sh;
				check_4_quit;
				pause;;

		\? )		help_0;
				endhelp;;
		1\? )		help_1;
				endhelp;;
		2\? )		help_2;
				endhelp;;
		3\? )		help_3;
				endhelp;;
		4\? )		help_4;
				endhelp;;

		"^" )		exit 2;;
		q | Q )		exit 1;;
	esac
done
