#! /bin/sh
#
#   Module name 		: loadsoft.sh 
#   Date of last delta		: 12/7/0
#   Release number		: 1.3


# Script name : loadsoft.sh
# Purpose     : Loads UBL software from media
# Author      : S. Roberts
# Revision    : 1.00
#
# Paramaters  : $1 = Package name
#               $2 = Filename to check for existance
#               $3 = d for directory, f for file, x for executable


PATH=$PATH:. ; export PATH

# Fix to make Linux "echo" process escape characters
os=`uname -s`
if [ "x${os}" = "xLinux" ]
then
	. linfix.sh
fi


set_attrs()
{
	case "$TERM" in
		vt100 | vt220 | vt320 | xterm | ansi )
					st_bl=`tput bold 2>/dev/null`;
					st_us=`tput smul 2>/dev/null`;
					norm=`tput sgr0 2>/dev/null`;;

		* )			st_bl=;
					st_us=;
					norm=;;
	esac
}


pause()
{
	echo
	echo "$spc Press [RETURN] to \c"
	if [ "$1" = "retry" ]
	then
		echo "retry: \c"
	else
		echo "continue: \c"
	fi
	read nothing
}


menu()
{
	cls.sh
	echo
	echo "$spc$st_us LOAD $p_name SYSTEM SOFTWARE FROM MEDIA $norm  Rev $rev"
	echo
	echo "$spc DEFAULT $p_name System Software Directory [$st_bl$ubb_path$norm]"
	echo "$spc Enter 'q' to QUIT, '^' to GO BACK, 'd' for DEFAULT or \c"
	echo "enter DIRECTORY PATH"
	echo
}


list_devices()
{
	echo "$st_bl\c" > delme.lis
	echo "Floppies:$norm" >> delme.lis
	ls -C /dev/fd* 2>/dev/null >> delme.lis
	echo >> delme.lis
	echo "$st_bl\c" >> delme.lis
	echo "Tapes:$norm" >> delme.lis
	ls -C /dev/rct* 2>/dev/null >> delme.lis
	ls -C /dev/rmt* 2>/dev/null >> delme.lis
	ls -C /dev/rmt/* 2>/dev/null >> delme.lis
	more delme.lis
	rm delme.lis
}


tar_files()
{
	device=$1
	tar_exit=false
	tar_stat=0
	rm -f zzzzzzzzzz 2>/dev/null
	while [ $tar_exit = false ]
	do
		if [ $device = "def" ]
		then
			tar -xv
		else
			tar -xvf $device
		fi
		tar_stat=$?
		if [ ! -f zzzzzzzzzz -a $tar_stat = 0 ]
		then
			carry_on
		else
			tar_exit=true
		fi
	done
	rm -f zzzzzzzzzz 2>/dev/null
}


def_no_tar()
{
	device=$1
	tar_exit=false
	tar_stat=0
	rm -f zzzzzzzzzz 2>/dev/null
	while [ $tar_exit = false ]
	do
		tar -xv$device
		tar_stat=$?
		if [ ! -f zzzzzzzzzz -a $tar_stat = 0 ]
		then
			carry_on
		else
			tar_exit=true
		fi
	done
	rm -f zzzzzzzzzz 2>/dev/null
}


carry_on()
{
	echo
	echo "$spc Please insert next tape/diskette and \c"
	echo "press [RETURN] to extract: $st_bl\c"
	read ans
	echo "$norm"
}


abortion()
{
	echo
	echo "$spc An error has occured reading media."
	echo
	echo "$spc Please ensure that the correct device is being used and"
	echo "$spc you have inserted the media in the correct drive with"
	echo "$spc the door closed."
	echo
}


load_ubb()
{
	if [ -r $ubb_path -a -w $ubb_path -a -x $ubb_path ]
	then
		load="Y"
		if [ -s $ubb_path/$f_name ]
		then
			echo
			echo "$spc $p_name already exists in directory $ubb_path"
			echo "$spc Enter 'q' to QUIT, '^' to GO BACK or \c"
			echo "'y' to OVERWRITE"
			ex_flag2=false
			while [ $ex_flag2 = false ]
			do
				echo "$spc Select option: $st_bl\c"
				read load
				echo "$norm\c"
				case $load in
					q | Q )		exit 1;;
					"^" )		load="N";
							ex_flag2=true;;
					y | Y )		ex_flag2=true;;
					* )		;;
				esac
			done
		fi
		if [ $load = "y" -o $load = "Y" ]
		then
			err_flag=true
			while [ $err_flag = true ]
			do
				cls.sh
				list_devices
				echo
				echo "$spc Please ensure that the first tape\c"
				echo "/diskette is in the drive."
				echo "$spc Enter 'q' to QUIT, name of Device \c"
				echo "or [RETURN] to use default: $st_bl\c"
				read device
				echo "$norm\c"
				if [ ${device:-" "} = " " ]
				then
					echo
					echo "$spc Using default device.       \c"
					echo "Please wait ..."
					cd $ubb_path
					tar_files def
					if [ $tar_stat != 0 ]
					then
						abortion
						pause retry
					else
						echo
						echo "$spc Loading software completed."
						echo
						err_flag=false
						ex_flag1=true
					fi
				else
					if [ $device = q -o $device = Q ]
					then
						exit 1
					fi

					if [ -b $device -o -c $device ]
					then
						if [ -r $device ]
						then
							echo
							echo "$spc Using device $device        \c"
							echo "Please wait ..."
							cd $ubb_path
							tar_files $device
							if [ $tar_stat != 0 ]
							then
								abortion
								pause retry
							else
								echo
								echo "$spc Loading software completed."
								echo
								err_flag=false
								ex_flag1=true
							fi
						else
							echo "$spc Can not open device $device"
							pause
						fi
					elif [ `echo $device|grep "^[0-9]*$" >/dev/null; echo $?` = 0 ]
					then
						echo
						echo "$spc Using device number $device.            \c"
						echo "Please wait ..."
						cd $ubb_path
						def_no_tar $device
						if [ $tar_stat != 0 ]
						then
							abortion
							pause retry
						else
							echo
							echo "$spc Loading software completed."
							echo
							err_flag=false
							ex_flag1=true
						fi
					else
						echo "$spc Can not find device $device"
						pause
					fi
				fi
			done
		fi
	else
		echo
		if [ -d $ubb_path ]
		then
			echo
			echo "$spc Permissions for $ubb_path needs setting to +rwx"
		else
			echo
			echo "$spc Directory $ubb_path not found"
			ubb_path=$old_ubb
		fi
		pause
	fi
}


# Main

p_name=$1
f_name=$2
f_type=$3
if [ -n "`pwd | grep usql`" ]
then
	p_name=${p_name:-'U/SQL'}
	f_name=${f_name:-'runusql'}
	f_type=${f_type:-'f'}
else
	p_name=${p_name:-'UBL'}
	f_name=${f_name:-'ubl'}
	f_type=${f_type:-'x'}
fi

rev="1.00"
set_attrs
spc=""
old_ubb=
ex_flag1=false
if [ -z "$ubb_path" ]
then
	ubb_path=`where.sh $f_name $f_type`
	if [ -z "${ubb_path}" ]
	then
	    ubb_path='.'
	else
	    ubb_path=`dirname $ubb_path`
	fi
fi
while [ $ex_flag1 = false ]
do
	menu
	echo "$spc Select option: $st_bl\c"
	read opt
	echo "$norm\c"
	case $opt in
		q | Q )		exit 1;;
		"^" )		exit 2;;
		d | D )		load_ubb;;
		"" )		;;
		* )		old_ubb=$ubb_path;
				ubb_path=$opt;
				load_ubb;;
	esac
done
