#! /bin/sh
#
#   Module name 		: perms.sh 
#   Date of last delta		: 12/7/0
#   Release number		: 1.3


# Script name : perms.sh
# Purpose     : Check or modify files and directory permissions.
# Author      : S. Roberts
# Revision    : 1.00


PATH=$PATH:. ; export PATH

# Fix to make Linux "echo" process escape characters
os=`uname -s`
if [ "x${os}" = "xLinux" ]
then
	. linfix.sh
fi


set_attrs()
{
	case "$TERM" in
		vt100 | vt220 | vt320 | xterm | ansi )
					st_bl=`tput bold 2>/dev/null`;
					st_us=`tput smul 2>/dev/null`;
					norm=`tput sgr0 2>/dev/null`;;

		* )			st_bl=;
					st_us=;
					norm=;;
	esac
}


menu()
{
	cls.sh
	echo
	echo "$spc        $st_us $PROD FILE PERMISSIONS ADMINISTRATION $norm  Rev $rev"
	echo
	echo "$spc 1)$st_bl checkperm.sh $norm        \c"
	echo "Check permissions on directory and files"
	echo "$spc 2)$st_bl modperm.sh $norm          \c"
	echo "Modify permissions on directory and files"
	echo
	echo "$spc '?' or '<NUMBER>?' for HELP, '^' to GO BACK or 'q' to QUIT\n"
}


pause()
{
	echo
	echo "$spc Press [RETURN] to continue: \c"
	read nothing
}


endhelp()
{
	echo "$spc Press [RETURN] to continue: $st_bl\c"
	read menu_ret
	echo "$norm\c"
}


help_0()
{
	echo
	echo "$spc The File Permissions Administration utility allows the user"
	echo "$spc to check or modify permissions on directories and files."
	echo
}


help_1()
{
	echo
	echo "$spc This option checks the permissions on a directory and all"
	echo "$spc of the files within it.  The current directory is used as a"
	echo "$spc default, but another can be specified."
	echo
	echo "$spc A warning is given if a subdirectory of the specified"
	echo "$spc directory fails to have +rwx permissions, and a warning for"
	echo "$spc any file that fails to have +rw permissions."
	echo
}


help_2()
{
	echo
	echo "$spc This option checks the permissions on a directory and all"
	echo "$spc of the files within it.  The current directory is used as a"
	echo "$spc default, but another can be specified."
	echo
	echo "$spc If a subdirectory of the specified directory doesn't have"
	echo "$spc rwx permissions, its permissions will be changed to rwx."
	echo
	echo "$spc If any file in the directory doesn't have rw permissions,"
	echo "$spc its permissions are changed to rw."
	echo
}


check_4_quit()
{
	if [ $? = "1" ]
	then
		exit 1
	fi
}


# Main
rev="1.00"
if [ -n "`pwd | grep usql`" ] ; then PROD="U/SQL" ; else PROD="UBL" ; fi
set_attrs
spc=""
ex_flag1=false
while [ $ex_flag1 = false ]
do
	menu
	echo "$spc Select option: $st_bl\c"
	read opt
	echo "$norm\c"
	case $opt in
		1 )		checkperm.sh -v;
				check_4_quit;
				pause;;
		2 )		modperm.sh -v;
				check_4_quit;
				pause;;

		\? )		help_0;
				endhelp;;
		1\? )		help_1;
				endhelp;;
		2\? )		help_2;
				endhelp;;

		"^" )		exit 2;;
		q | Q )		exit 1;;
	esac
done
