#! /bin/sh
#
#   Module name 		: seckey.sh 
#   Date of last delta		: 12/7/0
#   Release number		: 1.3


# Script name : seckey.sh
# Purpose     : Manages the security key installation/removal.
# Author      : S. Roberts
# Revision    : 1.0


PATH=$PATH:. ; export PATH

# Fix to make Linux "echo" process escape characters
os=`uname -s`
if [ "x${os}" = "xLinux" ]
then
	. linfix.sh
fi


set_attrs()
{
	case "$TERM" in
		vt100 | vt220 | vt320 | xterm | ansi )
					st_bl=`tput bold 2>/dev/null`;
					st_us=`tput smul 2>/dev/null`;
					norm=`tput sgr0 2>/dev/null`;;

		* )			st_bl=;
					st_us=;
					norm=;;
	esac
}


menu()
{
	echo
	echo "$spc        $st_us UBL SECURITY KEY ADMINISTRATION $norm  Rev $rev"
	echo
	echo "$spc 1)$st_bl addkey.sh $norm\c"
	echo "           Install the security key device driver"
	echo "$spc 2)$st_bl delkey.sh $norm\c"
	echo "           Removes the security key device driver"
	echo "$spc 3)$st_bl checkkey.sh $norm\c"
	echo "         Check if the security key is installed"
	echo
	echo "$spc '?' or '<NUMBER>?' for HELP, '^' to GO BACK or 'q' to QUIT\n"
}

endhelp()
{
	echo "$spc Press [RETURN] to continue: $st_bl\c"
	read menu_ret
	echo "$norm\c"
	menu
}

help_0()
{
	echo
	echo "$spc The UBL Security Key Administration utility allows the"
	echo "$spc user to add, remove or check if the UBL security key device"
	echo "$spc driver is installed on the system."
	echo
}


help_1()
{
	echo
	echo "$spc This option installs the security key device driver in"
	echo "$spc the Unix Kernel.  The user must be logged on as superuser in"
	echo "$spc order to use this option, as the script needs to be able to"
	echo "$spc create a new node for the datakey and perform other system"
	echo "$spc privileged operations."
	echo
	echo "$spc The user has to enter the name of the UBL system software"
	echo "$spc directory, so that the script can find the appropriate"
	echo "$spc device driver."
	echo
	echo "$spc The utility, addkey.sh, keeps a log file of all its"
	echo "$spc operations in:"
	echo "$spc   /etc/conf/cf.d/dk_install.log   on UNIX systems and"
	echo "$spc   /usr/sys/conf/dk_install.log    on Xenix systems."
	echo
}


help_2()
{
	echo
	echo "$spc This script removes the security key device driver from the"
	echo "$spc UNIX kernel.  The user must be logged on as superuser in"
	echo "$spc order to use this option."
	echo
	echo "$spc The utility, delkey.sh, keeps a log file of all its"
	echo "$spc operations stored in :"
	echo "$spc   /etc/conf/cf.d/dk_install.log   on Unix systems and"
	echo "$spc   /usr/sys/conf/dk_install.log    on Xenix systems."
	echo
}


help_3()
{
	echo
	echo "$spc This option uses a utility, checkkey.sh, to check if the"
	echo "$spc UBL security key device driver is installed on the system."
	echo
	echo "$spc The user must be logged on as superuser to use this option."
	echo
}


check_4_quit()
{
	if [ $? = "1" ]
	then
		exit 1
	fi
}


# Main
rev="1.00"
set_attrs
spc=""
cls.sh
menu
ex_flag1=false
while [ $ex_flag1 = false ]
do
	echo "$spc Select option: $st_bl\c"
	read opt
	echo "$norm\c"
	case $opt in
		1 )		addkey.sh;
				check_4_quit;
				menu;;
		2 )		delkey.sh;
				check_4_quit;
				menu;;
		3 )		checkkey.sh;
				check_4_quit;
				menu;;

		\? )		help_0;
				endhelp;;
		1\? )		help_1;
				endhelp;;
		2\? )		help_2;
				endhelp;;
		3\? )		help_3;
				endhelp;;

		"^" )		exit 2;;
		q | Q )		exit 1;;
		* )		cls.sh;
				menu;;
	esac
done
