#! /bin/sh
#
#   Module name 		: ubllp.sh 
#   Date of last delta		: 12/7/0
#   Release number		: 1.5


#  @(#)Script name : ubllp.sh
#  @(#)Description : Print a file to selected queue
#      Author      : S. Roberts
#  @(#)Revision    : 1.00


# Fix to make Linux "echo" process escape characters
os=`uname -s`
if [ "x${os}" = "xLinux" ]
then
	. linfix.sh
fi


set_attrs()
{
	case "$TERM" in
		vt100 | vt220 | vt320 | xterm | ansi )
					st_bl=`tput bold 2>/dev/null`;
					st_us=`tput smul 2>/dev/null`;
					norm=`tput sgr0 2>/dev/null`;;

		* )			st_bl=;
					st_us=;
					norm=;;
	esac
}


pause()
{
	echo
	echo "$spc Press <RETURN> to continue: \c"
	read nothing
}


ask4q_name()
{
	cls.sh
	echo
	echo "$spc Enter printer queue name: $st_bl\c"
	read q_name
	echo $norm
	echo $q_name > /tmp/lp.$$
}


get_f_name()
{
	while [ ! -f "$f_name" ]
	do
		cls.sh
		echo
		if [ $PROD = UBL ]
		then
			UPDNOTE=`ls UPDNOTE.[0-9][0-9][0-9]  2>/dev/null| sort | tail -1`
			if [ ! -z ""$UPDNOTE ]
			then
				echo "$spc Enter$st_bl $UPDNOTE $norm\c"
				echo "to print the U/BL update notice."
				echo
			fi
		fi
		echo "$spc Enter filename to print, or 'q' to QUIT: $st_bl\c"
		read f_name
		echo $norm
		if [ "$f_name" = q -o "$f_name" = Q ]
		then
			exit
		fi
		if [ ! -f "$f_name" ]
		then
			echo
			echo "$spc Invalid filename."
			pause
		fi
	done
}


checkq()
{
	# Make sure queue is actually a queue,
	# because IBM AIX prints silly headings on an lpstat -v

	read q
	while [ -n "$q" ]
	do
		lpstat -v$q >/dev/null 2>/dev/null
		if [ $? = 0 ]
		then
			echo $q
		fi
		read q
	done
}


get_names()
{
	lpstat -v | sed "s/.*for //;s/[\: ].*//" |
		sort | uniq | checkq > /tmp/lp.$$
}


get_name()
{
	name=`sed "$1 q" < /tmp/lp.$$ 2> /dev/null|tail -1`
}


printer_menu()
{
	ex_flag=false

	while [ $ex_flag = false ]
	do
		top_item=0
		cls.sh
		echo
		echo "$spc$st_us Available Printers On Your System $norm"
		echo

		for a
		do
			top_item=`expr $top_item + 1`
			#if [ "$a" = "Quit" ]; then echo; fi
			echo "$spc   $st_bl$top_item$norm   $a"
		done

		echo
		echo "$spc Select option (Q to quit): $st_bl\c"
		read opt
		echo "$norm\c"

		if [ -z "`echo $opt|tr -d '[0-9]'`" ]
		then
			if [ "$opt" -gt 0 -a "$opt" -le $top_item ]
			then
				get_name $opt
				ex_flag=true
			fi
		elif [ "$opt" = "q" -o "$opt" = "Q" ]
		then
			exit
		fi
	done
}


not_active()
{
	echo
	echo "$spc Printer is not active."
	echo
	if [ "`echo $f_name | sed 's/UPDNOTE.*/UPDNOTE/'`" = UPDNOTE ]
	then
		echo "$spc To print the Update Note at another time, type:"
		echo
		echo "$spc    ubllp.sh $f_name"
		echo
		echo "$spc from the UBL System Software Directory."
		echo
	else
		echo "$spc Abort."
		echo
	fi
}


indirect_approach()
{
	if [ `cat /tmp/lp.$$ | wc -l` = 1 ]
	then
		name=`cat /tmp/lp.$$`
	else
		printer_menu `cat /tmp/lp.$$`
	fi
	if [ no_lpstat = false ]
	then
		active=`lpstat -p$name | grep enable`
	else
		active="Assume it is active"
	fi
	if [ -z "$active" ]
	then
		not_active
	else
		get_f_name
		echo
		echo "$spc Sending to queue $name"
		pr $f_name | lp -d$name
	fi
}


print_direct()
{
	get_f_name
	cat $f_name > $device
	echo "Request sent to printer"
}


direct_approach()
{
	device=
	until [ -c "$device" ]
	do
		cls.sh > /tmp/mess.$$
		echo $st_bl >> /tmp/mess.$$
		echo "UNIX printer services not available." >> /tmp/mess.$$
		echo "Available printer devices:$norm" >> /tmp/mess.$$
		echo >> /tmp/mess.$$
		ls -C /dev/lp* 2>/dev/null >> /tmp/mess.$$
		echo >> /tmp/mess.$$
		more /tmp/mess.$$
		rm -f /tmp/mess.$$ 2>/dev/null

		echo "Device ('q' to QUIT): $st_bl\c"
		read device
		if [ "$device" = q -o "$device" = Q ]
		then
			exit
		fi
		echo "$norm\c"
	done
	echo
	echo "Using device $device"
	pause
	print_direct
}


f_name=$1
set_attrs
spc=

if [ -n "`pwd | grep usql`" ]
then
	PROD="U/SQL"
else
	PROD="UBL"
fi

rm -f /tmp/lp.$$ 2>/dev/null
if [ -z "`type lpstat | grep 'not found'`" ]
then
	get_names
	no_lpstat=false
else
	# No lpstat command on system.
	ask4q_name
	no_lpstat=true
fi
if [ -s /tmp/lp.$$ ]
then
	indirect_approach
else
	direct_approach
fi
rm /tmp/lp.$$
