#! /bin/sh
#
#   Module name 		: usrsoft.sh 
#   Date of last delta		: 12/7/0
#   Release number		: 1.3


# Script name : usrsoft.sh
# Purpose     : Create directorys for BB environment variables.
# Author      : S. Roberts
# Revision    : 1.00


PATH=$PATH:. ; export PATH

# Fix to make Linux "echo" process escape characters
os=`uname -s`
if [ "x${os}" = "xLinux" ]
then
	. linfix.sh
fi


set_attrs()
{
	case "$TERM" in
		vt100 | vt220 | vt320 | xterm | ansi )
					st_bl=`tput bold 2>/dev/null`;
					st_us=`tput smul 2>/dev/null`;
					norm=`tput sgr0 2>/dev/null`;;

		* )			st_bl=;
					st_us=;
					norm=;;
	esac
}


menu()
{
	cls.sh
	echo
	echo "$spc        $st_us UBL DIRECTORY STRUCTURE $norm  Rev $rev"
	echo
	echo "$spc 1)                      Creates BBROOT directory"
	echo "$spc 2)                      Creates BBPROGS directory"
	echo "$spc 3)                      Creates BBSOURCE directory"
	echo "$spc 4)                      Creates BBSEARCH directory"
	echo
	echo "$spc '?' or '<NUMBER>?' for HELP, '^' to GO BACK or 'q' to QUIT"
	echo
}


menu2()
{
	cls.sh
	echo
	echo "$spc$st_us CREATE UBL DIRECTORY STRUCTURE $norm  Rev $rev"
	echo
	echo "$spc DEFAULT Full pathname to BBENV [$st_bl$bbenv_path$norm]"
	echo "$spc Enter 'q' to QUIT, '^' to GO BACK, 'd' for DEFAULT or NEW FILE"
	echo
}


pause()
{
	echo
	echo "$spc Press [RETURN] to continue: \c"
	read nothing
}


endhelp()
{
	echo "$spc Press [RETURN] to continue: $st_bl\c"
	read menu_ret
	echo "$norm\c"
}


help_0()
{
	echo
	echo "$spc The UBL Directory Structure utility creates the"
	echo "$spc directories that are specified in the UBL environment"
	echo "$spc variable file (BBENV) for BBROOT, BBPROGS, BBSOURCE and"
	echo "$spc BBSEARCH (if they exist)."
	echo
	echo "$spc If they dont exist in your BBENV, you will be prompted"
	echo "$spc for an entry which will be appended to your BBENV."
	echo
}


help_1()
{
	echo
	echo "$spc This option will create the directory specified (if any)"
	echo "$spc by the BBROOT entry in the UBL environment variable file"
	echo "$spc (BBENV)."
	echo
	echo "$spc If none specified, you will be prompted for a BBROOT"
	echo "$spc entry which will be appended to your BBENV."
	echo
}


help_2()
{
	echo
	echo "$spc This option will create the directory specified (if any)"
	echo "$spc by the BBPROGS entry in the UBL environment variable file"
	echo "$spc (BBENV)."
	echo
	echo "$spc If none specified, you will be prompted for a BBPROGS"
	echo "$spc entry which will be appended to your BBENV."
	echo
}


help_3()
{
	echo
	echo "$spc This option will create the directory specified (if any)"
	echo "$spc by the BBSOURCE entry in the UBL environment variable file"
	echo "$spc (BBENV)."
	echo
	echo "$spc If none specified, you will be prompted for a BBSOURCE"
	echo "$spc entry which will be appended to your BBENV."
	echo
}


help_4()
{
	echo
	echo "$spc This option will create the directory specified (if any)"
	echo "$spc by the BBSEARCH entry in the UBL environment variable file"
	echo "$spc (BBENV)."
	echo
	echo "$spc If none specified, you will be prompted for a BBSEARCH"
	echo "$spc entry which will be appended to your BBENV."
	echo
}


find_bbenv()
{
	if [ -n "$BBENV" ]
	then
		bbenv_path=$BBENV
	else
		bbenv_path=`where.sh BBENV f`
	fi
}


check_bbenv()
{
	if [ -f "$opt" ]
	then
		bbenv_path=$opt
		main_menu
	else
		if [ -d "$opt" ]
		then
			echo
			echo "$spc $opt is not a file."
		else
			echo
			echo "$spc $opt not found."
		fi
		pause
	fi
}


chop_path()
{
	# Paramaters : $1 - Environment variable name

	BBwhat=$1
	ent_path=`cat $bbenv_path|grep $BBwhat|sed s/.*=//`
	if [ -z "$ent_path" ]
	then
		# No entry for variable in BBENV
		echo
		accept_ent $BBwhat
		prev_ent=false
	else
		echo
		echo "$spc Entry found in BBENV"
		echo
		prev_ent=true
	fi
	if [ "$ent_path" != "^" ]
	then
		ex_flag4=false
		while [ $ex_flag4 = false ]
		do
			create_dir `echo $ent_path|sed "s/:.*//"`
			ent_path=`echo $ent_path|sed "s/[^:]*//"|sed "s/[:]//"`
			if [ -z "$ent_path" ]
			then
				ex_flag4=true
			fi
		done
		if [ $prev_ent = false ]
		then
			add_to_bbenv $BBwhat
		fi

		# Initialise variables
		valid_path=""
		ent_path=""
	fi
}


accept_ent()
{
	# Paramaters : $1 - Environment variable name

	ex_flag3=false
	while [ $ex_flag3 = false ]
	do
		echo
		echo "$spc Enter 'q' to QUIT '^' to GO BACK or NEW DIRECTORY"
		echo "$spc $1 = $st_bl\c"
		read ent_path
		echo "$norm\c"
		case $ent_path in
			q | Q )		exit 1;;
			"^" )		ex_flag3=true;;
			"" )		;;
			* )		echo;
					ex_flag3=true;;
		esac
	done
}


add_to_bbenv()
{
	# Paramaters : $1 - Environment variable name
	
	if [ -w $bbenv_path ]
	then
		# Write entry in BBENV
		echo
		echo "$spc Updating $bbenv_path"
		echo "$1=$valid_path" >> $bbenv_path
	else
		echo
		echo "$spc Can not write to $bbenv_path"
	fi
}


create_dir()
{
	# Paramaters : $1 - Path to create directory

	if [ -d $1 -o -f $1 ]
	then
		if [ -z "$valid_path" ]
		then
			valid_path=$1
		else
			valid_path=$valid_path:$1
		fi
	else
		echo "$spc Creating directory $1"
		mkdir $1 2>/dev/null
		if [ $? != 0 ]
		then
			echo "$spc Unable to create directory $1"
		else
			if [ -z "$valid_path" ]
			then
				valid_path=$1
			else
				valid_path=$valid_path:$1
			fi
		fi
	fi
}


main_menu()
{
	ex_flag2=false
	while [ $ex_flag2 = false ]
	do
		menu
		echo "$spc Select option: $st_bl\c"
		read opt
		echo "$norm\c"
		case $opt in
			1 )		chop_path BBROOT;
					pause;;
			2 )		chop_path BBPROGS;
					pause;;
			3 )		chop_path BBSOURCE;
					pause;;
			4 )		chop_path BBSEARCH;
					pause;;

			\? )		help_0;
					endhelp;;
			1\? )		help_1;
					endhelp;;
			2\? )		help_2;
					endhelp;;
			3\? )		help_3;
					endhelp;;
			4\? )		help_4;
					endhelp;;

			"^" )		ex_flag2=true;;
			q | Q )		exit 1;;
			* )		;;
		esac
	done
}


# main
rev="1.00"
set_attrs
spc=""
ex_flag1=false
ex_flag2=false

bbenv_path=""
ent_path=""
valid_path=""
find_bbenv
while [ $ex_flag1 = false ]
do
	menu2
	echo "$spc Select option: $st_bl\c"
	read opt
	echo "$norm\c"
	case $opt in
		q | Q )		exit 1;;
		"^" )		exit 2;;
		d | D )		main_menu;;
		"" )		;;
		* )		check_bbenv;;
	esac
done
